@@ -18,11 +18,15 @@ DEFINITION="http://www.w3.org/2004/02/skos/core#definition"
 
 class Query:
 
-    def __init__(self, rag, user, collection, verbose):
+    def __init__(
+            self, rag, user, collection, verbose,
+            doc_limit=20
+    ):
         self.rag = rag
         self.user = user
         self.collection = collection
         self.verbose = verbose
+        self.doc_limit = doc_limit
 
     def get_vector(self, query):
 
@@ -44,7 +48,7 @@ class Query:
             print("Get entities...", flush=True)
 
         docs = self.rag.de_client.request(
-            vectors, limit=self.rag.doc_limit
+            vectors, limit=self.doc_limit
         )
 
         if self.verbose:
@@ -59,6 +63,7 @@ class DocumentRag:
     def __init__(
             self,
             pulsar_host="pulsar://pulsar:6650",
+            pulsar_api_key=None,
             pr_request_queue=None,
             pr_response_queue=None,
             emb_request_queue=None,
@@ -92,14 +97,12 @@ class DocumentRag:
         if self.verbose:
             print("Initialising...", flush=True)
 
-        # FIXME: Configurable
-        self.doc_limit = 20
-
         self.de_client = DocumentEmbeddingsClient(
             pulsar_host=pulsar_host,
             subscriber=module + "-de",
             input_queue=de_request_queue,
             output_queue=de_response_queue,
+            pulsar_api_key=pulsar_api_key,
         )            
 
         self.embeddings = EmbeddingsClient(
@@ -107,6 +110,7 @@ class DocumentRag:
             input_queue=emb_request_queue,
             output_queue=emb_response_queue,
             subscriber=module + "-emb",
+            pulsar_api_key=pulsar_api_key,
         )
 
         self.lang = PromptClient(
@@ -114,18 +118,23 @@ class DocumentRag:
             input_queue=pr_request_queue,
             output_queue=pr_response_queue,
             subscriber=module + "-de-prompt",
+            pulsar_api_key=pulsar_api_key,
         )
 
         if self.verbose:
             print("Initialised", flush=True)
 
-    def query(self, query, user="trustgraph", collection="default"):
+    def query(
+            self, query, user="trustgraph", collection="default",
+            doc_limit=20,
+    ):
 
         if self.verbose:
             print("Construct prompt...", flush=True)
 
         q = Query(
-            rag=self, user=user, collection=collection, verbose=self.verbose
+            rag=self, user=user, collection=collection, verbose=self.verbose,
+            doc_limit=doc_limit
         )
 
         docs = q.get_docs(query)
