@@ -7,10 +7,10 @@ from . endpoint import ServiceEndpoint
 from . requestor import ServiceRequestor
 
 class DocumentRagRequestor(ServiceRequestor):
-    def __init__(self, pulsar_host, timeout, auth):
+    def __init__(self, pulsar_client, timeout, auth):
 
         super(DocumentRagRequestor, self).__init__(
-            pulsar_host=pulsar_host,
+            pulsar_client=pulsar_client,
             request_queue=document_rag_request_queue,
             response_queue=document_rag_response_queue,
             request_schema=DocumentRagQuery,
@@ -23,6 +23,7 @@ class DocumentRagRequestor(ServiceRequestor):
             query=body["query"],
             user=body.get("user", "trustgraph"),
             collection=body.get("collection", "default"),
+            doc_limit=int(body.get("doc-limit", 20)),
         )
 
     def from_response(self, message):
