@@ -7,23 +7,23 @@ from aiohttp import WSMsgType
 from .. schema import Metadata
 from .. schema import Triples
 from .. schema import triples_store_queue
+from .. base import Publisher
 
-from . publisher import Publisher
 from . socket import SocketEndpoint
 from . serialize import to_subgraph
 
 class TriplesLoadEndpoint(SocketEndpoint):
 
-    def __init__(self, pulsar_host, auth, path="/api/v1/load/triples"):
+    def __init__(self, pulsar_client, auth, path="/api/v1/load/triples"):
 
         super(TriplesLoadEndpoint, self).__init__(
             endpoint_path=path, auth=auth,
         )
 
-        self.pulsar_host=pulsar_host
+        self.pulsar_client=pulsar_client
 
         self.publisher = Publisher(
-            self.pulsar_host, triples_store_queue,
+            self.pulsar_client, triples_store_queue,
             schema=JsonSchema(Triples)
         )
 
