@@ -30,6 +30,8 @@ class Processor(ConsumerProducer):
         output_queue = params.get("output_queue", default_output_queue)
         subscriber = params.get("subscriber", default_subscriber)
         store_uri = params.get("store_uri", default_store_uri)
+        #optional api key
+        api_key = params.get("api_key", None)
 
         super(Processor, self).__init__(
             **params | {
@@ -39,12 +41,13 @@ class Processor(ConsumerProducer):
                 "input_schema": DocumentEmbeddingsRequest,
                 "output_schema": DocumentEmbeddingsResponse,
                 "store_uri": store_uri,
+                "api_key": api_key,
             }
         )
 
-        self.client = QdrantClient(url=store_uri)
+        self.client = QdrantClient(url=store_uri, api_key=api_key)
 
-    def handle(self, msg):
+    async def handle(self, msg):
 
         try:
 
@@ -78,7 +81,7 @@ class Processor(ConsumerProducer):
 
             print("Send response...", flush=True)
             r = DocumentEmbeddingsResponse(documents=chunks, error=None)
-            self.producer.send(r, properties={"id": id})
+            await self.send(r, properties={"id": id})
 
             print("Done.", flush=True)
 
@@ -96,7 +99,7 @@ class Processor(ConsumerProducer):
                 documents=None,
             )
 
-            self.producer.send(r, properties={"id": id})
+            await self.send(r, properties={"id": id})
 
             self.consumer.acknowledge(msg)
 
@@ -111,10 +114,16 @@ class Processor(ConsumerProducer):
         parser.add_argument(
             '-t', '--store-uri',
             default=default_store_uri,
-            help=f'Milvus store URI (default: {default_store_uri})'
+            help=f'Qdrant store URI (default: {default_store_uri})'
+        )
+        
+        parser.add_argument(
+            '-k', '--api-key',
+            default=None,
+            help=f'API key for qdrant (default: None)'
         )
 
 def run():
 
-    Processor.start(module, __doc__)
+    Processor.launch(module, __doc__)
 
