@@ -58,7 +58,7 @@ class Processor(ConsumerProducer):
         else:
             return Value(value=ent, is_uri=False)
 
-    def handle(self, msg):
+    async def handle(self, msg):
 
         try:
 
@@ -297,7 +297,7 @@ class Processor(ConsumerProducer):
 
             print("Send response...", flush=True)
             r = TriplesQueryResponse(triples=triples, error=None)
-            self.producer.send(r, properties={"id": id})
+            await self.send(r, properties={"id": id})
 
             print("Done.", flush=True)
 
@@ -315,7 +315,7 @@ class Processor(ConsumerProducer):
                 response=None,
             )
 
-            self.producer.send(r, properties={"id": id})
+            await self.send(r, properties={"id": id})
 
             self.consumer.acknowledge(msg)
             
@@ -353,5 +353,5 @@ class Processor(ConsumerProducer):
 
 def run():
 
-    Processor.start(module, __doc__)
+    Processor.launch(module, __doc__)
 
